/*
 * Work under Copyright. Licensed under the EUPL.
 * See the project README.md and LICENSE.txt for more information.
 */

package net.dries007.tfc.client;

import java.util.Arrays;
import java.util.List;
import java.util.Set;

import net.minecraft.block.Block;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.GuiCreateWorld;
import net.minecraft.client.resources.I18n;
import net.minecraft.item.Item;
import net.minecraft.item.ItemBlock;
import net.minecraft.item.ItemStack;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.text.TextFormatting;
import net.minecraft.world.WorldType;
import net.minecraft.world.chunk.Chunk;
import net.minecraftforge.client.event.GuiScreenEvent;
import net.minecraftforge.client.event.RenderGameOverlayEvent;
import net.minecraftforge.event.entity.player.ItemTooltipEvent;
import net.minecraftforge.fml.client.registry.RenderingRegistry;
import net.minecraftforge.fml.common.Mod;
import net.minecraftforge.fml.common.eventhandler.EventPriority;
import net.minecraftforge.fml.common.eventhandler.SubscribeEvent;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import net.minecraftforge.oredict.OreDictionary;

import net.dries007.tfc.ConfigTFC;
import net.dries007.tfc.TerraFirmaCraft;
import net.dries007.tfc.client.render.RenderFallingBlockTFC;
import net.dries007.tfc.objects.entity.EntityFallingBlockTFC;
import net.dries007.tfc.util.CapabilityItemSize;
import net.dries007.tfc.util.IItemSize;
import net.dries007.tfc.util.IMetalObject;
import net.dries007.tfc.world.classic.CalenderTFC;
import net.dries007.tfc.world.classic.ClimateTFC;
import net.dries007.tfc.world.classic.chunkdata.ChunkDataProvider;
import net.dries007.tfc.world.classic.chunkdata.ChunkDataTFC;

import static net.dries007.tfc.Constants.MOD_ID;
import static net.minecraft.util.text.TextFormatting.*;

@Mod.EventBusSubscriber(value = Side.CLIENT, modid = MOD_ID)
public class ClientEvents
{
    public static void preInit()
    {
        RenderingRegistry.registerEntityRenderingHandler(EntityFallingBlockTFC.class, RenderFallingBlockTFC::new);
    }

    @SideOnly(Side.CLIENT)
    @SubscribeEvent(priority = EventPriority.HIGH)
    public static void openGUI(GuiScreenEvent.InitGuiEvent.Pre event)
    {
        if (ConfigTFC.CLIENT.makeWorldTypeClassicDefault && event.getGui() instanceof GuiCreateWorld)
        {
            GuiCreateWorld gui = ((GuiCreateWorld) event.getGui());
            // Only change if default is selected, because coming back from customisation, this will be set already.
            if (gui.field_146331_K == WorldType.field_77137_b.func_82747_f())
                gui.field_146331_K = TerraFirmaCraft.getWorldTypeTFC().func_82747_f();
        }
    }

    @SubscribeEvent
    @SideOnly(Side.CLIENT)
    public static void onRenderGameOverlayText(RenderGameOverlayEvent.Text event)
    {
        // todo: check if this is allowed to be displayed, debug/op only maybe?
        Minecraft mc = Minecraft.func_71410_x();
        List<String> list = event.getRight();
        if (ConfigTFC.GENERAL.debug && mc.field_71474_y.field_74330_P)
        {
            BlockPos blockpos = new BlockPos(mc.func_175606_aa().field_70165_t, mc.func_175606_aa().func_174813_aQ().field_72338_b, mc.func_175606_aa().field_70161_v);
            Chunk chunk = mc.field_71441_e.func_175726_f(blockpos);
            if (mc.field_71441_e.func_175667_e(blockpos) && !chunk.func_76621_g())
            {
                final int x = blockpos.func_177958_n() & 15, z = blockpos.func_177952_p() & 15;
                ChunkDataTFC data = chunk.getCapability(ChunkDataProvider.CHUNK_DATA_CAPABILITY, null);

                list.add("");
                list.add(AQUA + "TerraFirmaCraft");

                if (data == null || !data.isInitialized()) list.add("No data ?!");
                else
                {
                    list.add(String.format("%sTemps: Base: %s%.0f°%s Bio: %s%.0f°%s Height adjusted: %s%.0f°",
                            GRAY, WHITE, ClimateTFC.getTemp(mc.field_71441_e, blockpos), GRAY,
                            WHITE, ClimateTFC.getBioTemperatureHeight(mc.field_71441_e, blockpos), GRAY,
                            WHITE, ClimateTFC.getHeightAdjustedTemp(mc.field_71441_e, blockpos)
                    ));
                    list.add(String.format("%sTime: %s%02d:%02d %04d/%02d/%02d",
                            GRAY, WHITE,
                            CalenderTFC.getHourOfDay(),
                            CalenderTFC.getMinuteOfHour(),
                            CalenderTFC.getTotalYears(),
                            CalenderTFC.getMonthOfYear(),
                            CalenderTFC.getDayOfMonth()
                            )
                    );

                    list.add(GRAY + "Biome: " + WHITE + mc.field_71441_e.func_180494_b(blockpos).func_185359_l());

                    list.add(GRAY + "Rocks: " + WHITE + data.getRockLayer1(x, z).name + ", " + data.getRockLayer2(x, z).name + ", " + data.getRockLayer3(x, z).name);
                    list.add(GRAY + "EVT: " + WHITE + data.getEvtLayer(x, z).name);
                    list.add(GRAY + "Rainfall: " + WHITE + data.getRainfallLayer(x, z).name);
                    list.add(GRAY + "Stability: " + WHITE + data.getStabilityLayer(x, z).name);
                    list.add(GRAY + "Drainage: " + WHITE + data.getDrainageLayer(x, z).name);
                    list.add(GRAY + "Sea level offset: " + WHITE + data.getSeaLevelOffset(x, z));
                    list.add(GRAY + "Fish population: " + WHITE + data.getFishPopulation());

                    list.add("");
                    list.add(GRAY + "Rock at feet: " + WHITE + data.getRockLayerHeight(x, blockpos.func_177956_o(), z).name);

                    list.add("");
                    data.getOresSpawned().stream().map(String::valueOf).forEach(list::add);
                }
            }
        }
    }

    @SubscribeEvent
    @SideOnly(Side.CLIENT)
    public static void onItemTooltip(ItemTooltipEvent event)
    {
        ItemStack stack = event.getItemStack();
        Item item = stack.func_77973_b();
        List<String> tt = event.getToolTip();

        IItemSize size = CapabilityItemSize.getIItemSize(stack);
        if (size != null)
        {
            size.addSizeInfo(stack, tt);
        }

        if (event.getFlags().func_194127_a())
        {
            Set<String> toolClasses = item.getToolClasses(stack);
            if (!toolClasses.isEmpty())
            {
                tt.add("");
                for (String toolClass : toolClasses)
                {
                    tt.add(I18n.func_135052_a("tfc.tooltip.toolclass", toolClass));
                }
            }
            if (item instanceof IMetalObject)
                ((IMetalObject) item).addMetalInfo(stack, tt);
            if (item instanceof ItemBlock)
            {
                Block block = ((ItemBlock) item).func_179223_d();
                if (block instanceof IMetalObject)
                {
                    ((IMetalObject) block).addMetalInfo(stack, tt);
                }
            }

            int[] ids = OreDictionary.getOreIDs(stack);
            if (ids != null && ids.length != 0)
            {
                tt.add("");
                tt.add(TextFormatting.AQUA + "Ore Dictionary:");
                Arrays.stream(ids).mapToObj(OreDictionary::getOreName).sorted().forEachOrdered(tt::add);
            }
        }
    }
}
